BluetoothDevice class

Constructors

BluetoothDevice(String? name, String uuid, bool isConnected, {Stream<List<int>>? stream})

Properties

hashCode → int
The hash code for this object.
no setteroverride
isConnected → bool
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream ↔ Stream<List<int>>?
getter/setter pair
uuid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(dynamic other) → bool
The equality operator.
override