MethodChannelSimpleblue class

An implementation of SimplebluePlatform that uses method channels.

Inheritance

Constructors

MethodChannelSimpleblue()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String uuid) → Future
override
disconnect(String uuid) → Future
override
getDevices() → Future<List<BluetoothDevice>>
override
isTurnedOn() → Future<bool?>
override
listenConnectedDevice() → Stream<BluetoothDevice?>
override
listenStateChanges() → Stream<SimpleblueState>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanDevices({String? serviceUUID, int timeout = 10000}) → Stream<List<BluetoothDevice>>
override
stopScanning() → Future
override
toString() → String
A string representation of this object.
inherited
turnOff() → Future<bool?>
override
turnOn() → Future<bool?>
override
write(String uuid, List<int> data) → Future
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited