SimplebluePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SimplebluePlatform
Implementers

Constructors

SimplebluePlatform()
Constructs a SimplebluePlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String uuid) → Future
disconnect(String uuid) → Future
getDevices() → Future<List<BluetoothDevice>>
isTurnedOn() → Future<bool?>
listenConnectedDevice() → Stream<BluetoothDevice?>
listenStateChanges() → Stream<SimpleblueState>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanDevices({String? serviceUUID, int timeout = 10000}) → Stream<List<BluetoothDevice>>
stopScanning() → Future
toString() → String
A string representation of this object.
inherited
turnOff() → Future<bool?>
turnOn() → Future<bool?>
write(String uuid, List<int> data) → Future

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ SimplebluePlatform
The default instance of SimplebluePlatform to use.
getter/setter pair